==============================
 Working with transformations
==============================

.. inheritance-diagram:: matplotlib.transforms matplotlib.path
   :parts: 1

:mod:`matplotlib.transforms`
=============================

.. automodule:: matplotlib.transforms
   :members: TransformNode, BboxBase, Bbox, TransformedBbox, Transform,
       TransformWrapper, AffineBase, Affine2DBase, Affine2D, IdentityTransform,
       BlendedGenericTransform, BlendedAffine2D, blended_transform_factory,
       CompositeGenericTransform, CompositeAffine2D,
       composite_transform_factory, BboxTransform, BboxTransformTo,
       BboxTransformFrom, ScaledTranslation, TransformedPath, nonsingular,
       interval_contains, interval_contains_open
   :show-inheritance:

